@@ -47,6 +47,7 @@ app_category = 'android.intent.category.LAUNCHER'
 
 # ADB commands
 adb_install = 'adb install -g -t -r'
+adb_sdk_version = 'adb shell getprop ro.build.version.sdk'
 adb_start = 'adb shell am start -n {} -a {} -c {}'.format(app_activity, app_action, app_category)
 adb_stop = 'adb shell am force-stop {}'.format(app_name)
 adb_push = 'adb push'
@@ -91,8 +92,12 @@ def CreateReplayParser():
     parser.add_argument('--quit-after-measurement-range', action='store_true', default=False, help='If this is specified the replayer will abort when it reaches the <end_frame> specified in the --measurement-frame-range argument. (forwarded to replay tool)')
     parser.add_argument('--flush-measurement-range', action='store_true', default=False, help='If this is specified the replayer will flush and wait for all current GPU work to finish at the start and end of the measurement range. (forwarded to replay tool)')
     parser.add_argument('--flush-inside-measurement-range', action='store_true', default=False, help='If this is specified the replayer will flush and wait for all current GPU work to finish at end of each frame inside the measurement range. (forwarded to replay tool)')
+    parser.add_argument('--sgfs', '--skip-get-fence-status', metavar='STATUS', default=0, help='Specify behaviour to skip calls to vkWaitForFences and vkGetFenceStatus. Default is 0 - No skip (forwarded to replay tool)')
+    parser.add_argument('--sgfr', '--skip-get-fence-ranges', metavar='FRAME-RANGES', default='', help='Frame ranges where --sgfs applies. Default is all frames (forwarded to replay tool)')
+    parser.add_argument('--wait-before-present', action='store_true', default=False, help='Force wait on completion of queue operations for all queues before calling Present. This is needed for accurate acquisition of instrumentation data on some platforms.')
     parser.add_argument('-m', '--memory-translation', metavar='MODE', choices=['none', 'remap', 'realign', 'rebind'], help='Enable memory translation for replay on GPUs with memory types that are not compatible with the capture GPU\'s memory types.  Available modes are: none, remap, realign, rebind (forwarded to replay tool)')
     parser.add_argument('--swapchain', metavar='MODE', choices=['virtual', 'captured', 'offscreen'], help='Choose a swapchain mode to replay. Available modes are: virtual, captured, offscreen (forwarded to replay tool)')
+    parser.add_argument('--vssb', '--virtual-swapchain-skip-blit', action='store_true', default=False, help='Skip blit to real swapchain to gain performance during replay.')
     parser.add_argument('--use-captured-swapchain-indices', action='store_true', default=False, help='Same as "--swapchain captured". Ignored if the "--swapchain" option is used.')
     parser.add_argument('file', nargs='?', help='File on device to play (forwarded to replay tool)')
     return parser
@@ -182,27 +187,38 @@ def MakeExtrasString(args):
 
     if args.quit_after_measurement_range:
         arg_list.append('--quit-after-measurement-range')
-        arg_list.append('{}'.format(args.quit_after_measurement_range))
 
     if args.flush_measurement_range:
         arg_list.append('--flush-measurement-range')
-        arg_list.append('{}'.format(args.flush_measurement_range))
 
     if args.flush_inside_measurement_range:
         arg_list.append('--flush-inside-measurement-range')
-        arg_list.append('{}'.format(args.flush_inside_measurement_range))
 
     if args.swapchain:
         arg_list.append('--swapchain')
         arg_list.append('{}'.format(args.swapchain))
-    
+
     if args.offscreen_swapchain_frame_boundary:
         arg_list.append('--offscreen-swapchain-frame-boundary')
 
+    if args.vssb:
+        arg_list.append('--vssb')
+
+    if args.sgfs:
+        arg_list.append('--sgfs')
+        arg_list.append('{}'.format(args.sgfs))
+
+    if args.sgfr:
+        arg_list.append('--sgfr')
+        arg_list.append('{}'.format(args.sgfr))
+
     if args.memory_translation:
         arg_list.append('-m')
         arg_list.append('{}'.format(args.memory_translation))
 
+    if args.wait_before_present:
+        arg_list.append('--wait-before-present')
+
     if args.file:
         arg_list.append(args.file)
     elif not args.version:
@@ -214,7 +230,9 @@ def MakeExtrasString(args):
 def InstallApk(install_args):
     install_parser = CreateInstallApkParser()
     args = install_parser.parse_args(install_args)
-    cmd = adb_install + ' ' + args.file
+    sdk = int(subprocess.check_output(shlex.split(adb_sdk_version)).decode())
+    force_queryable = ' --force-queryable' if sdk >= 30 else ''
+    cmd = adb_install + force_queryable + ' ' + args.file
     print('Executing:', cmd)
     subprocess.check_call(shlex.split(cmd, posix='win' not in sys.platform))
 
