@@ -40,6 +40,9 @@
 #if defined(VK_USE_PLATFORM_ANDROID_KHR)
 #include "application/android_context.h"
 #endif
+#if defined(VK_USE_PLATFORM_METAL_EXT)
+#include "application/metal_context.h"
+#endif
 #if defined(VK_USE_PLATFORM_DISPLAY_KHR)
 #include "application/display_context.h"
 #endif
@@ -271,6 +274,13 @@ void Application::InitializeWsiContext(const char* pSurfaceExtensionName, void*
         }
         else
 #endif
+#if defined(VK_USE_PLATFORM_METAL_EXT)
+            if (!util::platform::StringCompare(pSurfaceExtensionName, VK_EXT_METAL_SURFACE_EXTENSION_NAME))
+        {
+            wsi_contexts_[VK_EXT_METAL_SURFACE_EXTENSION_NAME] = std::make_unique<MetalContext>(this);
+        }
+        else
+#endif
 #if defined(VK_USE_PLATFORM_DISPLAY_KHR)
             if (!util::platform::StringCompare(pSurfaceExtensionName, VK_KHR_DISPLAY_EXTENSION_NAME))
         {
