@@ -1,6 +1,7 @@
 /*
 ** Copyright (c) 2018,2020 Valve Corporation
 ** Copyright (c) 2018,2020 LunarG, Inc.
+** Copyright (c) 2023 Advanced Micro Devices, Inc. All rights reserved.
 **
 ** Permission is hereby granted, free of charge, to any person obtaining a
 ** copy of this software and associated documentation files (the "Software"),
@@ -45,7 +46,8 @@ class Win32Window : public decode::Window
                         const int32_t      xpos,
                         const int32_t      ypos,
                         const uint32_t     width,
-                        const uint32_t     height) override;
+                        const uint32_t     height,
+                        bool               force_windowed = false) override;
 
     virtual bool Destroy() override;
 
@@ -66,12 +68,13 @@ class Win32Window : public decode::Window
 
     virtual std::string GetWsiExtension() const override;
 
-    virtual VkResult CreateSurface(const encode::InstanceTable* table,
-                                   VkInstance                   instance,
-                                   VkFlags                      flags,
-                                   VkSurfaceKHR*                pSurface) override;
+    virtual VkResult CreateSurface(const encode::VulkanInstanceTable* table,
+                                   VkInstance                         instance,
+                                   VkFlags                            flags,
+                                   VkSurfaceKHR*                      pSurface) override;
 
-    virtual void DestroySurface(const encode::InstanceTable* table, VkInstance instance, VkSurfaceKHR surface) override;
+    virtual void
+    DestroySurface(const encode::VulkanInstanceTable* table, VkInstance instance, VkSurfaceKHR surface) override;
 
   private:
     HWND          hwnd_;
@@ -82,6 +85,7 @@ class Win32Window : public decode::Window
     uint32_t      screen_height_;
     bool          fullscreen_;
     HINSTANCE     hinstance_;
+    bool          force_windowed_;
 };
 
 class Win32WindowFactory : public decode::WindowFactory
@@ -91,14 +95,17 @@ class Win32WindowFactory : public decode::WindowFactory
 
     virtual const char* GetSurfaceExtensionName() const override { return VK_KHR_WIN32_SURFACE_EXTENSION_NAME; }
 
-    virtual decode::Window*
-    Create(const int32_t x, const int32_t y, const uint32_t width, const uint32_t height) override;
+    virtual decode::Window* Create(const int32_t  x,
+                                   const int32_t  y,
+                                   const uint32_t width,
+                                   const uint32_t height,
+                                   bool           force_windowed = false) override;
 
     void Destroy(decode::Window* window) override;
 
-    virtual VkBool32 GetPhysicalDevicePresentationSupport(const encode::InstanceTable* table,
-                                                          VkPhysicalDevice             physical_device,
-                                                          uint32_t                     queue_family_index) override;
+    virtual VkBool32 GetPhysicalDevicePresentationSupport(const encode::VulkanInstanceTable* table,
+                                                          VkPhysicalDevice                   physical_device,
+                                                          uint32_t queue_family_index) override;
 
   private:
     Win32Context* win32_context_;
