@@ -515,5 +515,13 @@ void VulkanDecoderBase::DispatchSetTlasToBlasDependencyCommand(format::HandleId
     }
 }
 
+void VulkanDecoderBase::SetCurrentBlockIndex(uint64_t block_index)
+{
+    for (auto consumer : consumers_)
+    {
+        consumer->SetCurrentBlockIndex(block_index);
+    }
+}
+
 GFXRECON_END_NAMESPACE(decode)
 GFXRECON_END_NAMESPACE(gfxrecon)
