@@ -1,5 +1,5 @@
 /*
-** Copyright (c) 2020-2022 LunarG, Inc.
+** Copyright (c) 2020-2023 LunarG, Inc.
 **
 ** Permission is hereby granted, free of charge, to any person obtaining a
 ** copy of this software and associated documentation files (the "Software"),
@@ -151,12 +151,12 @@ void ClearObjects(VulkanObjectInfoTable* table,
     }
 }
 
-void FreeAllLiveObjects(VulkanObjectInfoTable*                                   table,
-                        bool                                                     remove_entries,
-                        bool                                                     report_leaks,
-                        std::function<const encode::InstanceTable*(const void*)> get_instance_table,
-                        std::function<const encode::DeviceTable*(const void*)>   get_device_table,
-                        VulkanSwapchain*                                         swapchain)
+void FreeAllLiveObjects(VulkanObjectInfoTable*                                         table,
+                        bool                                                           remove_entries,
+                        bool                                                           report_leaks,
+                        std::function<const encode::VulkanInstanceTable*(const void*)> get_instance_table,
+                        std::function<const encode::VulkanDeviceTable*(const void*)>   get_device_table,
+                        VulkanSwapchain*                                               swapchain)
 {
     FreeChildObjects<DeviceInfo, EventInfo>(
         table,
@@ -663,15 +663,7 @@ void FreeAllLiveObjects(VulkanObjectInfoTable*
         [&](const InstanceInfo* parent_info, const SurfaceKHRInfo* object_info) {
             assert((parent_info != nullptr) && (object_info != nullptr));
             auto table  = get_instance_table(parent_info->handle);
-            auto window = object_info->window;
-            if (window != nullptr)
-            {
-                window->DestroySurface(table, parent_info->handle, object_info->handle);
-            }
-            else
-            {
-                table->DestroySurfaceKHR(parent_info->handle, object_info->handle, nullptr);
-            }
+            swapchain->DestroySurface(table->DestroySurfaceKHR, parent_info, object_info, nullptr);
         });
 
     FreeParentObjects<DeviceInfo>(table,
@@ -717,11 +709,11 @@ void FreeAllLiveObjects(VulkanObjectInfoTable*
     }
 }
 
-void FreeAllLiveInstances(VulkanObjectInfoTable*                                   table,
-                          bool                                                     remove_entries,
-                          bool                                                     report_leaks,
-                          std::function<const encode::InstanceTable*(const void*)> get_instance_table,
-                          std::function<const encode::DeviceTable*(const void*)>   get_device_table)
+void FreeAllLiveInstances(VulkanObjectInfoTable*                                         table,
+                          bool                                                           remove_entries,
+                          bool                                                           report_leaks,
+                          std::function<const encode::VulkanInstanceTable*(const void*)> get_instance_table,
+                          std::function<const encode::VulkanDeviceTable*(const void*)>   get_device_table)
 {
     FreeParentObjects<InstanceInfo>(table,
                                     remove_entries,
