@@ -34,18 +34,18 @@ GFXRECON_BEGIN_NAMESPACE(gfxrecon)
 GFXRECON_BEGIN_NAMESPACE(decode)
 GFXRECON_BEGIN_NAMESPACE(object_cleanup)
 
-void FreeAllLiveObjects(VulkanObjectInfoTable*                                   table,
-                        bool                                                     remove_entries,
-                        bool                                                     report_leaks,
-                        std::function<const encode::InstanceTable*(const void*)> get_instance_table,
-                        std::function<const encode::DeviceTable*(const void*)>   get_device_table,
-                        VulkanSwapchain*                                         swapchain);
+void FreeAllLiveObjects(VulkanObjectInfoTable*                                         table,
+                        bool                                                           remove_entries,
+                        bool                                                           report_leaks,
+                        std::function<const encode::VulkanInstanceTable*(const void*)> get_instance_table,
+                        std::function<const encode::VulkanDeviceTable*(const void*)>   get_device_table,
+                        VulkanSwapchain*                                               swapchain);
 
-void FreeAllLiveInstances(VulkanObjectInfoTable*                                   table,
-                          bool                                                     remove_entries,
-                          bool                                                     report_leaks,
-                          std::function<const encode::InstanceTable*(const void*)> get_instance_table,
-                          std::function<const encode::DeviceTable*(const void*)>   get_device_table);
+void FreeAllLiveInstances(VulkanObjectInfoTable*                                         table,
+                          bool                                                           remove_entries,
+                          bool                                                           report_leaks,
+                          std::function<const encode::VulkanInstanceTable*(const void*)> get_instance_table,
+                          std::function<const encode::VulkanDeviceTable*(const void*)>   get_device_table);
 
 GFXRECON_END_NAMESPACE(object_cleanup)
 GFXRECON_END_NAMESPACE(decode)
