@@ -23,6 +23,7 @@
 #include "decode/vulkan_virtual_swapchain.h"
 
 #include "decode/vulkan_resource_allocator.h"
+#include "decode/decoder_util.h"
 
 #include <array>
 
@@ -47,7 +48,7 @@ VkResult VulkanVirtualSwapchain::CreateSwapchainKHR(VkResult
                                                     const VkSwapchainCreateInfoKHR*       create_info,
                                                     const VkAllocationCallbacks*          allocator,
                                                     HandlePointerDecoder<VkSwapchainKHR>* swapchain,
-                                                    const encode::DeviceTable*            device_table)
+                                                    const encode::VulkanDeviceTable*      device_table)
 {
     VkDevice                 device = VK_NULL_HANDLE;
     VkSurfaceCapabilitiesKHR surfCapabilities{};
@@ -234,7 +235,8 @@ VkResult VulkanVirtualSwapchain::CreateSwapchainResourceData(const DeviceInfo*
                           transfer_queue_family_index,
                           swapchain_info->capture_id);
     }
-    device_table_->GetDeviceQueue(device, copy_queue_family_index, 0, &initial_copy_queue);
+
+    initial_copy_queue = GetDeviceQueue(device_table_, device_info, copy_queue_family_index, 0);
     if (initial_copy_queue == VK_NULL_HANDLE)
     {
         GFXRECON_LOG_ERROR("Virtual swapchain failed getting device queue %d to create initial virtual swapchain "
@@ -615,8 +617,9 @@ VkResult VulkanVirtualSwapchain::AcquireNextImageKHR(VkResult                  o
     }
 
     result = func(device, swapchain, timeout, semaphore, fence, image_index);
-    if (result != VK_SUCCESS)
+    if ((result != VK_SUCCESS) && (result != VK_SUBOPTIMAL_KHR))
     {
+        // TODO: Add some handling of optimization with VK_SUBOPTIMAL_KHR.
         GFXRECON_LOG_ERROR("Virtual swapchain failed AcquireNextImageKHR 0x%08x for swapchain (ID = %" PRIu64 ")",
                            result,
                            swapchain_info->capture_id);
@@ -640,8 +643,9 @@ VkResult VulkanVirtualSwapchain::AcquireNextImage2KHR(VkResult
     }
 
     VkResult result = func(device, acquire_info, image_index);
-    if (result != VK_SUCCESS)
+    if ((result != VK_SUCCESS) && (result != VK_SUBOPTIMAL_KHR))
     {
+        // TODO: Add some handling of optimization with VK_SUBOPTIMAL_KHR.
         GFXRECON_LOG_ERROR("Virtual swapchain failed AcquireNextImage2KHR 0x%08x for swapchain (ID = %" PRIu64 ")",
                            result,
                            swapchain_info->capture_id);
@@ -661,6 +665,13 @@ VkResult VulkanVirtualSwapchain::QueuePresentKHR(VkResult
     {
         return VK_ERROR_FEATURE_NOT_PRESENT;
     }
+    else if (swapchain_options_.skip_additional_present_blts)
+    {
+        // If we're to skip the BLT, just go ahead and perform the present even thought it won't
+        // produce the valid image to the screen.  The intent for this path is mostly for performance
+        // evaluation.
+        return func(queue_info->handle, present_info);
+    }
 
     VkQueue  queue              = queue_info->handle;
     uint32_t queue_family_index = queue_info->family_index;
