@@ -1,6 +1,7 @@
 /*
 ** Copyright (c) 2018,2020 Valve Corporation
 ** Copyright (c) 2018,2020 LunarG, Inc.
+** Copyright (c) 2023 Advanced Micro Devices, Inc. All rights reserved.
 **
 ** Permission is hereby granted, free of charge, to any person obtaining a
 ** copy of this software and associated documentation files (the "Software"),
@@ -60,7 +61,8 @@ class Window
                         const int32_t      xpos,
                         const int32_t      ypos,
                         const uint32_t     width,
-                        const uint32_t     height) = 0;
+                        const uint32_t     height,
+                        bool               force_windowed = false) = 0;
 
     virtual bool Destroy() = 0;
 
@@ -80,10 +82,13 @@ class Window
 
     virtual std::string GetWsiExtension() const = 0;
 
-    virtual VkResult
-    CreateSurface(const encode::InstanceTable* table, VkInstance instance, VkFlags flags, VkSurfaceKHR* pSurface) = 0;
+    virtual VkResult CreateSurface(const encode::VulkanInstanceTable* table,
+                                   VkInstance                         instance,
+                                   VkFlags                            flags,
+                                   VkSurfaceKHR*                      pSurface) = 0;
 
-    virtual void DestroySurface(const encode::InstanceTable* table, VkInstance instance, VkSurfaceKHR surface) = 0;
+    virtual void
+    DestroySurface(const encode::VulkanInstanceTable* table, VkInstance instance, VkSurfaceKHR surface) = 0;
 };
 
 class WindowFactory
@@ -95,13 +100,14 @@ class WindowFactory
 
     virtual const char* GetSurfaceExtensionName() const = 0;
 
-    virtual Window* Create(const int32_t x, const int32_t y, const uint32_t width, const uint32_t height) = 0;
+    virtual Window* Create(
+        const int32_t x, const int32_t y, const uint32_t width, const uint32_t height, bool force_windowed = false) = 0;
 
     virtual void Destroy(Window* window) = 0;
 
-    virtual VkBool32 GetPhysicalDevicePresentationSupport(const encode::InstanceTable* table,
-                                                          VkPhysicalDevice             physical_device,
-                                                          uint32_t                     queue_family_index) = 0;
+    virtual VkBool32 GetPhysicalDevicePresentationSupport(const encode::VulkanInstanceTable* table,
+                                                          VkPhysicalDevice                   physical_device,
+                                                          uint32_t                           queue_family_index) = 0;
 };
 
 GFXRECON_END_NAMESPACE(decode)
