@@ -727,6 +727,10 @@ CaptureSettings::ParseMemoryTrackingModeString(const std::string&
     {
         result = MemoryTrackingMode::kPageGuard;
     }
+    else if (util::platform::StringCompareNoCase("userfaultfd", value_string.c_str()) == 0)
+    {
+        result = MemoryTrackingMode::kUserfaultfd;
+    }
     else if (util::platform::StringCompareNoCase("assisted", value_string.c_str()) == 0)
     {
         result = MemoryTrackingMode::kAssisted;
