@@ -309,6 +309,9 @@ void EncodeStruct(ParameterEncoder* encoder, const D3D12_VERSIONED_ROOT_SIGNATUR
         case D3D_ROOT_SIGNATURE_VERSION_1_1:
             EncodeStruct(encoder, value.Desc_1_1);
             break;
+        case D3D_ROOT_SIGNATURE_VERSION_1_2:
+            EncodeStruct(encoder, value.Desc_1_2);
+            break;
         default:
             break;
     }
@@ -385,6 +388,9 @@ void EncodeStruct(ParameterEncoder* encoder, const D3D12_VERSIONED_DEVICE_REMOVE
         case D3D12_DRED_VERSION_1_2:
             EncodeStruct(encoder, value.Dred_1_2);
             break;
+        case D3D12_DRED_VERSION_1_3:
+            EncodeStruct(encoder, value.Dred_1_3);
+            break;
         default:
             break;
     }
