@@ -25,7 +25,7 @@
 #ifndef GFXRECON_ENCODE_D3D12_CAPTURE_MANAGER_H
 #define GFXRECON_ENCODE_D3D12_CAPTURE_MANAGER_H
 
-#include "encode/capture_manager.h"
+#include "encode/api_capture_manager.h"
 
 #include <cassert>
 #include <stdint.h>
@@ -41,15 +41,17 @@
 GFXRECON_BEGIN_NAMESPACE(gfxrecon)
 GFXRECON_BEGIN_NAMESPACE(encode)
 
-class D3D12CaptureManager : public CaptureManager
+class D3D12CaptureManager : public ApiCaptureManager
 {
   public:
-    static D3D12CaptureManager* Get() { return instance_; }
-
+    static D3D12CaptureManager* Get() { return singleton_; }
     // Creates the capture manager instance if none exists, or increments a reference count if an instance already
     // exists.
     static bool CreateInstance();
 
+    static D3D12CaptureManager* InitSingleton();
+    static void                 DestroySingleton();
+
     // Decrement the instance reference count, releasing resources when the count reaches zero.  Ignored if the count is
     // already zero.
     static void DestroyInstance();
@@ -157,7 +159,7 @@ class D3D12CaptureManager : public CaptureManager
     template <typename ParentWrapper>
     void EndCreateMethodCallCapture(HRESULT result, REFIID riid, void** handle, ParentWrapper* create_object_wrapper)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && SUCCEEDED(result))
+        if (IsCaptureModeTrack() && SUCCEEDED(result))
         {
             if ((handle != nullptr) && (*handle != nullptr))
             {
@@ -184,7 +186,7 @@ class D3D12CaptureManager : public CaptureManager
                                          GetHandlesFunc             func,
                                          GetHandlesArgs... args)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
 
@@ -205,7 +207,7 @@ class D3D12CaptureManager : public CaptureManager
         {
             resource_value_annotator_->RemoveObjectGPUVA(wrapper);
         }
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             state_tracker_->RemoveEntry(wrapper);
             state_tracker_->TrackRelease(wrapper);
@@ -740,7 +742,7 @@ class D3D12CaptureManager : public CaptureManager
   protected:
     D3D12CaptureManager();
 
-    virtual ~D3D12CaptureManager() override {}
+    virtual ~D3D12CaptureManager() {}
 
     virtual void CreateStateTracker() override { state_tracker_ = std::make_unique<Dx12StateTracker>(); }
 
@@ -789,8 +791,8 @@ class D3D12CaptureManager : public CaptureManager
     bool                          RvAnnotationActive();
 
     void                              PrePresent(IDXGISwapChain_Wrapper* wrapper);
-    void                              PostPresent(IDXGISwapChain_Wrapper* wrapper);
-    static D3D12CaptureManager*       instance_;
+    void                              PostPresent(IDXGISwapChain_Wrapper* wrapper, UINT flags);
+    static D3D12CaptureManager*       singleton_;
     std::set<ID3D12Resource_Wrapper*> mapped_resources_; ///< Track mapped resources for unassisted tracking mode.
     DxgiDispatchTable  dxgi_dispatch_table_;  ///< DXGI dispatch table for functions retrieved from the DXGI DLL.
     D3D12DispatchTable d3d12_dispatch_table_; ///< D3D12 dispatch table for functions retrieved from the D3D12 DLL.
