@@ -1,31 +1,31 @@
 /*
-** Copyright (c) 2018-2021 Valve Corporation
-** Copyright (c) 2018-2023 LunarG, Inc.
-** Copyright (c) 2019-2023 Advanced Micro Devices, Inc. All rights reserved.
-**
-** Permission is hereby granted, free of charge, to any person obtaining a
-** copy of this software and associated documentation files (the "Software"),
-** to deal in the Software without restriction, including without limitation
-** the rights to use, copy, modify, merge, publish, distribute, sublicense,
-** and/or sell copies of the Software, and to permit persons to whom the
-** Software is furnished to do so, subject to the following conditions:
-**
-** The above copyright notice and this permission notice shall be included in
-** all copies or substantial portions of the Software.
-**
-** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-** IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-** FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-** AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-** LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-** FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-** DEALINGS IN THE SOFTWARE.
-*/
+ ** Copyright (c) 2018-2021 Valve Corporation
+ ** Copyright (c) 2018-2023 LunarG, Inc.
+ ** Copyright (c) 2019-2023 Advanced Micro Devices, Inc. All rights reserved.
+ **
+ ** Permission is hereby granted, free of charge, to any person obtaining a
+ ** copy of this software and associated documentation files (the "Software"),
+ ** to deal in the Software without restriction, including without limitation
+ ** the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ ** and/or sell copies of the Software, and to permit persons to whom the
+ ** Software is furnished to do so, subject to the following conditions:
+ **
+ ** The above copyright notice and this permission notice shall be included in
+ ** all copies or substantial portions of the Software.
+ **
+ ** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ ** IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ ** FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ ** AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ ** LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ ** FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ ** DEALINGS IN THE SOFTWARE.
+ */
 
 #ifndef GFXRECON_ENCODE_VULKAN_CAPTURE_MANAGER_H
 #define GFXRECON_ENCODE_VULKAN_CAPTURE_MANAGER_H
 
-#include "encode/capture_manager.h"
+#include "encode/api_capture_manager.h"
 
 #include "encode/capture_settings.h"
 #include "encode/descriptor_update_template_info.h"
@@ -54,15 +54,18 @@
 GFXRECON_BEGIN_NAMESPACE(gfxrecon)
 GFXRECON_BEGIN_NAMESPACE(encode)
 
-class VulkanCaptureManager : public CaptureManager
+class VulkanCaptureManager : public ApiCaptureManager
 {
   public:
-    static VulkanCaptureManager* Get() { return instance_; }
+    static VulkanCaptureManager* Get() { return singleton_; }
 
     // Creates the capture manager instance if none exists, or increments a reference count if an instance already
     // exists.
     static bool CreateInstance();
 
+    static VulkanCaptureManager* InitSingleton();
+    static void                  DestroySingleton();
+
     // Decrement the instance reference count, releasing resources when the count reaches zero.  Ignored if the count is
     // already zero.
     static void DestroyInstance();
@@ -77,7 +80,7 @@ class VulkanCaptureManager : public CaptureManager
     // the appropriate resource cleanup.
     static void CheckVkCreateInstanceStatus(VkResult result);
 
-    static const LayerTable* GetLayerTable() { return &layer_table_; }
+    static const VulkanLayerTable* GetLayerTable() { return &vulkan_layer_table_; }
 
     void InitVkInstance(VkInstance* instance, PFN_vkGetInstanceProcAddr gpa);
 
@@ -90,7 +93,7 @@ class VulkanCaptureManager : public CaptureManager
                                  typename Wrapper::HandleType* handle,
                                  const CreateInfo*             create_info)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && result == VK_SUCCESS)
+        if (IsCaptureModeTrack() && result == VK_SUCCESS)
         {
             assert(state_tracker_ != nullptr);
 
@@ -112,7 +115,7 @@ class VulkanCaptureManager : public CaptureManager
                                      typename Wrapper::HandleType* handles,
                                      const AllocateInfo*           alloc_info)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS) && (handles != nullptr))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS) && (handles != nullptr))
         {
             assert(state_tracker_ != nullptr);
 
@@ -135,7 +138,7 @@ class VulkanCaptureManager : public CaptureManager
                                       typename Wrapper::HandleType* handles,
                                       const CreateInfo*             create_infos)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) &&
+        if (IsCaptureModeTrack() &&
             ((result == VK_SUCCESS) || (result == VK_OPERATION_DEFERRED_KHR) ||
              (result == VK_OPERATION_NOT_DEFERRED_KHR) || (result == VK_INCOMPLETE)) &&
             (handles != nullptr))
@@ -166,7 +169,7 @@ class VulkanCaptureManager : public CaptureManager
                                             HandleStruct*                          handle_structs,
                                             std::function<Wrapper*(HandleStruct*)> unwrap_struct_handle)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && ((result == VK_SUCCESS) || (result == VK_INCOMPLETE)) &&
+        if (IsCaptureModeTrack() && ((result == VK_SUCCESS) || (result == VK_INCOMPLETE)) &&
             (handle_structs != nullptr))
         {
             assert(state_tracker_ != nullptr);
@@ -189,7 +192,7 @@ class VulkanCaptureManager : public CaptureManager
     template <typename Wrapper>
     void EndDestroyApiCallCapture(typename Wrapper::HandleType handle)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->RemoveEntry<Wrapper>(handle);
@@ -202,7 +205,7 @@ class VulkanCaptureManager : public CaptureManager
     template <typename Wrapper>
     void EndDestroyApiCallCapture(uint32_t count, const typename Wrapper::HandleType* handles)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (handles != nullptr))
+        if (IsCaptureModeTrack() && (handles != nullptr))
         {
             assert(state_tracker_ != nullptr);
 
@@ -220,7 +223,8 @@ class VulkanCaptureManager : public CaptureManager
         if ((call_id == format::ApiCallId::ApiCall_vkBeginCommandBuffer) ||
             (call_id == format::ApiCallId::ApiCall_vkResetCommandBuffer))
         {
-            auto cmd_buffer_wrapper = GetWrapper<CommandBufferWrapper>(command_buffer);
+            auto cmd_buffer_wrapper =
+                vulkan_wrappers::GetWrapper<vulkan_wrappers::CommandBufferWrapper>(command_buffer);
             GFXRECON_ASSERT(cmd_buffer_wrapper != nullptr);
             cmd_buffer_wrapper->is_frame_boundary = false;
         }
@@ -231,7 +235,7 @@ class VulkanCaptureManager : public CaptureManager
         auto thread_data = GetThreadData();
         GFXRECON_ASSERT(thread_data != nullptr);
 
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackCommand(command_buffer, thread_data->call_id_, thread_data->parameter_buffer_.get());
@@ -248,7 +252,7 @@ class VulkanCaptureManager : public CaptureManager
         auto thread_data = GetThreadData();
         GFXRECON_ASSERT(thread_data != nullptr);
 
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackCommand(
@@ -344,8 +348,7 @@ class VulkanCaptureManager : public CaptureManager
                                                               uint32_t*                pQueueFamilyPropertyCount,
                                                               VkQueueFamilyProperties* pQueueFamilyProperties)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (pQueueFamilyPropertyCount != nullptr) &&
-            (pQueueFamilyProperties != nullptr))
+        if (IsCaptureModeTrack() && (pQueueFamilyPropertyCount != nullptr) && (pQueueFamilyProperties != nullptr))
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackPhysicalDeviceQueueFamilyProperties(
@@ -358,8 +361,7 @@ class VulkanCaptureManager : public CaptureManager
                                                                uint32_t*                 pQueueFamilyPropertyCount,
                                                                VkQueueFamilyProperties2* pQueueFamilyProperties)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (pQueueFamilyPropertyCount != nullptr) &&
-            (pQueueFamilyProperties != nullptr))
+        if (IsCaptureModeTrack() && (pQueueFamilyPropertyCount != nullptr) && (pQueueFamilyProperties != nullptr))
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackPhysicalDeviceQueueFamilyProperties2(
@@ -373,7 +375,7 @@ class VulkanCaptureManager : public CaptureManager
                                                           VkSurfaceKHR     surface,
                                                           VkBool32*        pSupported)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS) && (pSupported != nullptr))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS) && (pSupported != nullptr))
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackPhysicalDeviceSurfaceSupport(physicalDevice, queueFamilyIndex, surface, *pSupported);
@@ -385,8 +387,7 @@ class VulkanCaptureManager : public CaptureManager
                                                                VkSurfaceKHR              surface,
                                                                VkSurfaceCapabilitiesKHR* pSurfaceCapabilities)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS) &&
-            (pSurfaceCapabilities != nullptr))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS) && (pSurfaceCapabilities != nullptr))
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackPhysicalDeviceSurfaceCapabilities(physicalDevice, surface, pSurfaceCapabilities);
@@ -400,8 +401,7 @@ class VulkanCaptureManager : public CaptureManager
     {
         GFXRECON_UNREFERENCED_PARAMETER(physicalDevice);
 
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS) &&
-            (pSurfaceCapabilities != nullptr))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS) && (pSurfaceCapabilities != nullptr))
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackPhysicalDeviceSurfaceCapabilities2(
@@ -415,8 +415,8 @@ class VulkanCaptureManager : public CaptureManager
                                                           uint32_t*           pSurfaceFormatCount,
                                                           VkSurfaceFormatKHR* pSurfaceFormats)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS) &&
-            (pSurfaceFormatCount != nullptr) && (pSurfaceFormats != nullptr))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS) && (pSurfaceFormatCount != nullptr) &&
+            (pSurfaceFormats != nullptr))
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackPhysicalDeviceSurfaceFormats(
@@ -430,8 +430,8 @@ class VulkanCaptureManager : public CaptureManager
                                                            uint32_t*                              pSurfaceFormatCount,
                                                            VkSurfaceFormat2KHR*                   pSurfaceFormats)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS) &&
-            (pSurfaceFormatCount != nullptr) && (pSurfaceFormats != nullptr))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS) && (pSurfaceFormatCount != nullptr) &&
+            (pSurfaceFormats != nullptr))
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackPhysicalDeviceSurfaceFormats2(
@@ -447,7 +447,7 @@ class VulkanCaptureManager : public CaptureManager
     {
         if ((pPresentModeCount != nullptr) && (pPresentModes != nullptr))
         {
-            if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS))
+            if (IsCaptureModeTrack() && (result == VK_SUCCESS))
             {
                 assert(state_tracker_ != nullptr);
                 state_tracker_->TrackPhysicalDeviceSurfacePresentModes(
@@ -488,8 +488,7 @@ class VulkanCaptureManager : public CaptureManager
                                            VkFence     fence,
                                            uint32_t*   index)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) &&
-            ((result == VK_SUCCESS) || (result == VK_SUBOPTIMAL_KHR)))
+        if (IsCaptureModeTrack() && ((result == VK_SUCCESS) || (result == VK_SUBOPTIMAL_KHR)))
         {
             assert((state_tracker_ != nullptr) && (index != nullptr));
             state_tracker_->TrackSemaphoreSignalState(semaphore);
@@ -502,8 +501,7 @@ class VulkanCaptureManager : public CaptureManager
                                             const VkAcquireNextImageInfoKHR* pAcquireInfo,
                                             uint32_t*                        index)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) &&
-            ((result == VK_SUCCESS) || (result == VK_SUBOPTIMAL_KHR)))
+        if (IsCaptureModeTrack() && ((result == VK_SUCCESS) || (result == VK_SUBOPTIMAL_KHR)))
         {
             assert((state_tracker_ != nullptr) && (pAcquireInfo != nullptr) && (index != nullptr));
             state_tracker_->TrackSemaphoreSignalState(pAcquireInfo->semaphore);
@@ -517,8 +515,7 @@ class VulkanCaptureManager : public CaptureManager
 
     void PostProcess_vkQueuePresentKHR(VkResult result, VkQueue queue, const VkPresentInfoKHR* pPresentInfo)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) &&
-            ((result == VK_SUCCESS) || (result == VK_SUBOPTIMAL_KHR)))
+        if (IsCaptureModeTrack() && ((result == VK_SUCCESS) || (result == VK_SUBOPTIMAL_KHR)))
         {
             assert((state_tracker_ != nullptr) && (pPresentInfo != nullptr));
             state_tracker_->TrackSemaphoreSignalState(
@@ -533,7 +530,7 @@ class VulkanCaptureManager : public CaptureManager
     void PostProcess_vkQueueBindSparse(
         VkResult result, VkQueue, uint32_t bindInfoCount, const VkBindSparseInfo* pBindInfo, VkFence)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS))
         {
             assert((state_tracker_ != nullptr) && ((bindInfoCount == 0) || (pBindInfo != nullptr)));
             for (uint32_t i = 0; i < bindInfoCount; ++i)
@@ -759,7 +756,7 @@ class VulkanCaptureManager : public CaptureManager
     void PostProcess_vkBindBufferMemory(
         VkResult result, VkDevice device, VkBuffer buffer, VkDeviceMemory memory, VkDeviceSize memoryOffset)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS))
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackBufferMemoryBinding(device, buffer, memory, memoryOffset);
@@ -771,7 +768,7 @@ class VulkanCaptureManager : public CaptureManager
                                          uint32_t                      bindInfoCount,
                                          const VkBindBufferMemoryInfo* pBindInfos)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS) && (pBindInfos != nullptr))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS) && (pBindInfos != nullptr))
         {
             assert(state_tracker_ != nullptr);
 
@@ -789,7 +786,7 @@ class VulkanCaptureManager : public CaptureManager
     void PostProcess_vkBindImageMemory(
         VkResult result, VkDevice device, VkImage image, VkDeviceMemory memory, VkDeviceSize memoryOffset)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS))
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackImageMemoryBinding(device, image, memory, memoryOffset);
@@ -801,7 +798,7 @@ class VulkanCaptureManager : public CaptureManager
                                         uint32_t                     bindInfoCount,
                                         const VkBindImageMemoryInfo* pBindInfos)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS) && (pBindInfos != nullptr))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS) && (pBindInfos != nullptr))
         {
             assert(state_tracker_ != nullptr);
 
@@ -817,7 +814,7 @@ class VulkanCaptureManager : public CaptureManager
                                           const VkRenderPassBeginInfo* pRenderPassBegin,
                                           VkSubpassContents)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackBeginRenderPass(commandBuffer, pRenderPassBegin);
@@ -828,7 +825,7 @@ class VulkanCaptureManager : public CaptureManager
                                            const VkRenderPassBeginInfo* pRenderPassBegin,
                                            const VkSubpassBeginInfoKHR*)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackBeginRenderPass(commandBuffer, pRenderPassBegin);
@@ -837,7 +834,7 @@ class VulkanCaptureManager : public CaptureManager
 
     void PostProcess_vkCmdEndRenderPass(VkCommandBuffer commandBuffer)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackEndRenderPass(commandBuffer);
@@ -846,7 +843,7 @@ class VulkanCaptureManager : public CaptureManager
 
     void PostProcess_vkCmdEndRenderPass2(VkCommandBuffer commandBuffer, const VkSubpassEndInfoKHR*)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackEndRenderPass(commandBuffer);
@@ -864,7 +861,7 @@ class VulkanCaptureManager : public CaptureManager
                                           uint32_t                    imageMemoryBarrierCount,
                                           const VkImageMemoryBarrier* pImageMemoryBarriers)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackImageBarriers(commandBuffer, imageMemoryBarrierCount, pImageMemoryBarriers);
@@ -873,7 +870,7 @@ class VulkanCaptureManager : public CaptureManager
 
     void PostProcess_vkCmdPipelineBarrier2KHR(VkCommandBuffer commandBuffer, const VkDependencyInfoKHR* pDependencyInfo)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackImageBarriers2KHR(
@@ -885,7 +882,7 @@ class VulkanCaptureManager : public CaptureManager
                                           uint32_t               commandBufferCount,
                                           const VkCommandBuffer* pCommandBuffers)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackExecuteCommands(commandBuffer, commandBufferCount, pCommandBuffers);
@@ -894,7 +891,7 @@ class VulkanCaptureManager : public CaptureManager
 
     void PostProcess_vkTrimCommandPool(VkDevice device, VkCommandPool commandPool, VkCommandPoolTrimFlags)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackTrimCommandPool(device, commandPool);
@@ -903,7 +900,7 @@ class VulkanCaptureManager : public CaptureManager
 
     void PostProcess_vkResetCommandPool(VkResult result, VkDevice, VkCommandPool commandPool, VkCommandPoolResetFlags)
     {
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS))
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackResetCommandPool(commandPool);
@@ -915,7 +912,7 @@ class VulkanCaptureManager : public CaptureManager
     {
         PostQueueSubmit();
 
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS))
         {
             assert((state_tracker_ != nullptr) && ((submitCount == 0) || (pSubmits != nullptr)));
 
@@ -940,7 +937,8 @@ class VulkanCaptureManager : public CaptureManager
 
             for (uint32_t j = 0; j < pSubmits[i].commandBufferCount; ++j)
             {
-                auto cmd_buffer_wrapper = GetWrapper<CommandBufferWrapper>(pSubmits[i].pCommandBuffers[j]);
+                auto cmd_buffer_wrapper =
+                    vulkan_wrappers::GetWrapper<vulkan_wrappers::CommandBufferWrapper>(pSubmits[i].pCommandBuffers[j]);
                 if (CheckCommandBufferWrapperForFrameBoundary(cmd_buffer_wrapper))
                 {
                     break;
@@ -954,7 +952,7 @@ class VulkanCaptureManager : public CaptureManager
     {
         PostQueueSubmit();
 
-        if (((GetCaptureMode() & kModeTrack) == kModeTrack) && (result == VK_SUCCESS))
+        if (IsCaptureModeTrack() && (result == VK_SUCCESS))
         {
             assert((state_tracker_ != nullptr) && ((submitCount == 0) || (pSubmits != nullptr)));
 
@@ -979,8 +977,8 @@ class VulkanCaptureManager : public CaptureManager
 
             for (uint32_t j = 0; j < pSubmits[i].commandBufferInfoCount; ++j)
             {
-                auto cmd_buffer_wrapper =
-                    GetWrapper<CommandBufferWrapper>(pSubmits[i].pCommandBufferInfos[j].commandBuffer);
+                auto cmd_buffer_wrapper = vulkan_wrappers::GetWrapper<vulkan_wrappers::CommandBufferWrapper>(
+                    pSubmits[i].pCommandBufferInfos[j].commandBuffer);
                 if (CheckCommandBufferWrapperForFrameBoundary(cmd_buffer_wrapper))
                 {
                     break;
@@ -995,7 +993,7 @@ class VulkanCaptureManager : public CaptureManager
                                             uint32_t                    descriptorCopyCount,
                                             const VkCopyDescriptorSet*  pDescriptorCopies)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackUpdateDescriptorSets(
@@ -1008,7 +1006,7 @@ class VulkanCaptureManager : public CaptureManager
                                                        VkDescriptorUpdateTemplate descriptorUpdateTemplate,
                                                        const void*                pData)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             TrackUpdateDescriptorSetWithTemplate(descriptorSet, descriptorUpdateTemplate, pData);
         }
@@ -1019,7 +1017,7 @@ class VulkanCaptureManager : public CaptureManager
                                                           VkDescriptorUpdateTemplate descriptorUpdateTemplate,
                                                           const void*                pData)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             TrackUpdateDescriptorSetWithTemplate(descriptorSet, descriptorUpdateTemplate, pData);
         }
@@ -1059,13 +1057,13 @@ class VulkanCaptureManager : public CaptureManager
     {
         if (result == VK_SUCCESS)
         {
-            if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+            if (IsCaptureModeTrack())
             {
                 assert(state_tracker_ != nullptr);
                 state_tracker_->TrackResetDescriptorPool(descriptorPool);
             }
 
-            ResetDescriptorPoolWrapper(descriptorPool);
+            vulkan_wrappers::ResetDescriptorPoolWrapper(descriptorPool);
         }
     }
 
@@ -1074,17 +1072,18 @@ class VulkanCaptureManager : public CaptureManager
                                      uint32_t            query,
                                      VkQueryControlFlags flags)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
-            state_tracker_->TrackQueryActivation(commandBuffer, queryPool, query, flags, QueryInfo::kInvalidIndex);
+            state_tracker_->TrackQueryActivation(
+                commandBuffer, queryPool, query, flags, vulkan_state_info::QueryInfo::kInvalidIndex);
         }
     }
 
     void PostProcess_vkCmdBeginQueryIndexedEXT(
         VkCommandBuffer commandBuffer, VkQueryPool queryPool, uint32_t query, VkQueryControlFlags flags, uint32_t index)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackQueryActivation(commandBuffer, queryPool, query, flags, index);
@@ -1096,10 +1095,11 @@ class VulkanCaptureManager : public CaptureManager
                                          VkQueryPool             queryPool,
                                          uint32_t                query)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
-            state_tracker_->TrackQueryActivation(commandBuffer, queryPool, query, 0, QueryInfo::kInvalidIndex);
+            state_tracker_->TrackQueryActivation(
+                commandBuffer, queryPool, query, 0, vulkan_state_info::QueryInfo::kInvalidIndex);
         }
     }
 
@@ -1108,10 +1108,11 @@ class VulkanCaptureManager : public CaptureManager
                                           VkQueryPool              queryPool,
                                           uint32_t                 query)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
-            state_tracker_->TrackQueryActivation(commandBuffer, queryPool, query, 0, QueryInfo::kInvalidIndex);
+            state_tracker_->TrackQueryActivation(
+                commandBuffer, queryPool, query, 0, vulkan_state_info::QueryInfo::kInvalidIndex);
         }
     }
 
@@ -1137,7 +1138,7 @@ class VulkanCaptureManager : public CaptureManager
                                          uint32_t        firstQuery,
                                          uint32_t        queryCount)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackQueryReset(commandBuffer, queryPool, firstQuery, queryCount);
@@ -1146,7 +1147,7 @@ class VulkanCaptureManager : public CaptureManager
 
     void PostProcess_vkResetQueryPool(VkDevice, VkQueryPool queryPool, uint32_t firstQuery, uint32_t queryCount)
     {
-        if ((GetCaptureMode() & kModeTrack) == kModeTrack)
+        if (IsCaptureModeTrack())
         {
             assert(state_tracker_ != nullptr);
             state_tracker_->TrackQueryReset(queryPool, firstQuery, queryCount);
@@ -1258,13 +1259,19 @@ class VulkanCaptureManager : public CaptureManager
 #endif
 
   protected:
-    VulkanCaptureManager() : CaptureManager(format::ApiFamilyId::ApiFamily_Vulkan) {}
+    VulkanCaptureManager() : ApiCaptureManager(format::ApiFamilyId::ApiFamily_Vulkan) {}
 
-    virtual ~VulkanCaptureManager() override {}
+    virtual ~VulkanCaptureManager() {}
 
-    virtual void CreateStateTracker() override { state_tracker_ = std::make_unique<VulkanStateTracker>(); }
+    virtual void CreateStateTracker() override
+    {
+        state_tracker_ = std::make_unique<VulkanStateTracker>();
+    }
 
-    virtual void DestroyStateTracker() override { state_tracker_ = nullptr; }
+    virtual void DestroyStateTracker() override
+    {
+        state_tracker_ = nullptr;
+    }
 
     virtual void WriteTrackedState(util::FileOutputStream* file_stream, format::ThreadId thread_id) override;
 
@@ -1307,29 +1314,30 @@ class VulkanCaptureManager : public CaptureManager
     void
     ProcessEnumeratePhysicalDevices(VkResult result, VkInstance instance, uint32_t count, VkPhysicalDevice* devices);
 
-    VkMemoryPropertyFlags GetMemoryProperties(DeviceWrapper* device_wrapper, uint32_t memory_type_index);
+    VkMemoryPropertyFlags GetMemoryProperties(vulkan_wrappers::DeviceWrapper* device_wrapper,
+                                              uint32_t                        memory_type_index);
 
     const VkImportAndroidHardwareBufferInfoANDROID*
     FindAllocateMemoryExtensions(const VkMemoryAllocateInfo* allocate_info);
 
-    bool ProcessReferenceToAndroidHardwareBuffer(VkDevice device, AHardwareBuffer* hardware_buffer);
+    void ProcessReferenceToAndroidHardwareBuffer(VkDevice device, AHardwareBuffer* hardware_buffer);
     void ProcessImportAndroidHardwareBuffer(VkDevice device, VkDeviceMemory memory, AHardwareBuffer* hardware_buffer);
     void ReleaseAndroidHardwareBuffer(AHardwareBuffer* hardware_buffer);
     bool CheckBindAlignment(VkDeviceSize memoryOffset);
 
-    bool CheckCommandBufferWrapperForFrameBoundary(const CommandBufferWrapper* command_buffer_wrapper);
+    bool CheckCommandBufferWrapperForFrameBoundary(const vulkan_wrappers::CommandBufferWrapper* command_buffer_wrapper);
 
     bool CheckPNextChainForFrameBoundary(const VkBaseInStructure* current);
 
   private:
     void QueueSubmitWriteFillMemoryCmd();
 
-    static VulkanCaptureManager*        instance_;
-    static LayerTable                   layer_table_;
-    std::set<DeviceMemoryWrapper*>      mapped_memory_; // Track mapped memory for unassisted tracking mode.
-    std::unique_ptr<VulkanStateTracker> state_tracker_;
-    HardwareBufferMap                   hardware_buffers_;
-    std::mutex                          deferred_operation_mutex;
+    static VulkanCaptureManager*                    singleton_;
+    static VulkanLayerTable                         vulkan_layer_table_;
+    std::set<vulkan_wrappers::DeviceMemoryWrapper*> mapped_memory_; // Track mapped memory for unassisted tracking mode.
+    std::unique_ptr<VulkanStateTracker>             state_tracker_;
+    HardwareBufferMap                               hardware_buffers_;
+    std::mutex                                      deferred_operation_mutex;
 };
 
 GFXRECON_END_NAMESPACE(encode)
