@@ -35,6 +35,43 @@ GFXRECON_BEGIN_NAMESPACE(graphics)
 
 class Dx12ResourceDataUtil
 {
+  public:
+    enum CopyType : int
+    {
+        kCopyTypeRead  = 0,
+        kCopyTypeWrite = 1
+    };
+
+    static void GetResourceCopyInfo(ID3D12Resource*                                  resource,
+                                    size_t&                                          subresource_count,
+                                    std::vector<uint64_t>&                           subresource_offsets,
+                                    std::vector<uint64_t>&                           subresource_sizes,
+                                    std::vector<D3D12_PLACED_SUBRESOURCE_FOOTPRINT>& layouts,
+                                    uint64_t&                                        total_size,
+                                    ID3D12Device*                                    device = nullptr);
+
+    static HRESULT
+    RecordCommandsToCopyResource(ID3D12GraphicsCommandList*                             target_command_list,
+                                 ID3D12Resource*                                        target_resource,
+                                 CopyType                                               copy_type,
+                                 uint64_t                                               copy_size,
+                                 const std::vector<D3D12_PLACED_SUBRESOURCE_FOOTPRINT>& subresource_layouts,
+                                 const std::vector<dx12::ResourceStateInfo>&            before_states,
+                                 const std::vector<dx12::ResourceStateInfo>&            after_states,
+                                 ID3D12Resource*                                        staging_buffer);
+
+    static bool IsResourceCpuAccessible(ID3D12Resource* resource, CopyType copy_type);
+
+    static HRESULT MapSubresourceAndReadData(ID3D12Resource* resource, UINT subresource, size_t size, uint8_t* data);
+
+    static HRESULT
+    MapSubresourceAndWriteData(ID3D12Resource* resource, UINT subresource, size_t size, const uint8_t* data);
+
+    static dx12::ID3D12ResourceComPtr
+    CreateStagingBuffer(ID3D12Device* device, CopyType type, uint64_t required_buffer_size);
+
+    static size_t GetSubresourceCount(ID3D12Resource* resource);
+
   public:
     Dx12ResourceDataUtil(ID3D12Device* device, uint64_t min_buffer_size);
 
@@ -47,7 +84,7 @@ class Dx12ResourceDataUtil
                              std::vector<uint8_t>&                       data,
                              std::vector<uint64_t>&                      subresource_offsets,
                              std::vector<uint64_t>&                      subresource_sizes,
-                             ID3D12Resource*                             staging_resource = nullptr);
+                             ID3D12Resource*                             staging_buffer_for_batching = nullptr);
 
     HRESULT WriteToResource(ID3D12Resource*                             target_resource,
                             bool                                        try_map_and_copy,
@@ -56,36 +93,12 @@ class Dx12ResourceDataUtil
                             const std::vector<uint8_t>&                 data,
                             const std::vector<uint64_t>&                subresource_offsets,
                             const std::vector<uint64_t>&                subresource_sizes,
-                            ID3D12Resource*                             staging_resource = nullptr,
-                            bool                                        batching         = false);
-
-    enum CopyType : int
-    {
-        kCopyTypeRead  = 0,
-        kCopyTypeWrite = 1
-    };
+                            ID3D12Resource*                             staging_buffer_for_batching = nullptr);
 
     // Create a mappable buffer used to copy data to or from another resource via a command list.
     dx12::ID3D12ResourceComPtr GetStagingBuffer(CopyType type, uint64_t required_buffer_size);
     dx12::ID3D12ResourceComPtr CreateStagingBuffer(CopyType type, uint64_t required_buffer_size);
 
-    void GetResourceCopyInfo(ID3D12Resource*                                  resource,
-                             size_t&                                          subresource_count,
-                             std::vector<uint64_t>&                           subresource_offsets,
-                             std::vector<uint64_t>&                           subresource_sizes,
-                             std::vector<D3D12_PLACED_SUBRESOURCE_FOOTPRINT>& layouts,
-                             uint64_t&                                        total_size);
-
-    // Copy data to or from a mappable resource. Also transitions the resource to after_states.
-    bool CopyMappableResource(ID3D12Resource*                             target_resource,
-                              const std::vector<dx12::ResourceStateInfo>& before_states,
-                              const std::vector<dx12::ResourceStateInfo>& after_states,
-                              CopyType                                    copy_type,
-                              std::vector<uint8_t>*                       read_data,
-                              const std::vector<uint8_t>*                 write_data,
-                              const std::vector<uint64_t>&                subresource_offsets,
-                              const std::vector<uint64_t>&                subresource_sizes);
-
     HRESULT ExecuteAndWaitForCommandList();
 
     // Build and execute a command list that copies data to or from the target_resource.
@@ -110,11 +123,15 @@ class Dx12ResourceDataUtil
                                  const std::vector<dx12::ResourceStateInfo>& before_states,
                                  const std::vector<dx12::ResourceStateInfo>& after_states);
 
-    HRESULT MapSubresourceAndReadData(ID3D12Resource* resource, UINT subresource, size_t size, uint8_t* data);
-
-    HRESULT MapSubresourceAndWriteData(ID3D12Resource* resource, UINT subresource, size_t size, const uint8_t* data);
-
   private:
+    // Copy data to or from a mappable resource.
+    static bool CopyMappableResource(ID3D12Resource*              target_resource,
+                                     CopyType                     copy_type,
+                                     std::vector<uint8_t>*        read_data,
+                                     const std::vector<uint8_t>*  write_data,
+                                     const std::vector<uint64_t>& subresource_offsets,
+                                     const std::vector<uint64_t>& subresource_sizes);
+
     ID3D12Device*                         device_;
     dx12::ID3D12CommandQueueComPtr        command_queue_;
     dx12::ID3D12CommandAllocatorComPtr    command_allocator_;
@@ -127,8 +144,6 @@ class Dx12ResourceDataUtil
 
     // Temporary buffers.
     std::vector<D3D12_PLACED_SUBRESOURCE_FOOTPRINT> temp_subresource_layouts_;
-    std::vector<UINT>                               temp_subresource_row_counts_;
-    std::vector<UINT64>                             temp_subresource_row_size_bytes_;
 
     // Vector to Resident resources
     std::vector<ID3D12Pageable*> resident_resources;
