@@ -36,12 +36,13 @@ GFXRECON_BEGIN_NAMESPACE(graphics)
 class FpsInfo
 {
   public:
-    FpsInfo(uint64_t               measurement_start_frame = 1,
-            uint64_t               measurement_end_frame   = std::numeric_limits<uint64_t>::max(),
-            bool                   has_measurement_range   = false,
-            bool                   quit_after_range        = false,
-            bool                   flush_measurement_range = false,
-            const std::string_view measurement_file_name   = "");
+    FpsInfo(uint64_t               measurement_start_frame        = 1,
+            uint64_t               measurement_end_frame          = std::numeric_limits<uint64_t>::max(),
+            bool                   has_measurement_range          = false,
+            bool                   quit_after_range               = false,
+            bool                   flush_measurement_range        = false,
+            bool                   flush_inside_measurement_range = false,
+            const std::string_view measurement_file_name          = "");
 
     void LogToConsole();
 
@@ -69,6 +70,7 @@ class FpsInfo
     bool has_measurement_range_;
     bool quit_after_range_;
     bool flush_measurement_range_;
+    bool flush_inside_measurement_range_;
 
     bool started_measurement_;
     bool ended_measurement_;
