@@ -32,6 +32,10 @@
 #include "util/to_string.h"
 #include "format/format.h"
 
+#ifndef WIN32
+#include "format/platform_types.h"
+#endif
+
 #include "nlohmann/json.hpp"
 
 GFXRECON_BEGIN_NAMESPACE(gfxrecon)
@@ -61,14 +65,16 @@ struct JsonOptions
     bool        hex_handles   = false;
 };
 
-void FieldToJson(nlohmann::ordered_json& jdata, short data, const JsonOptions& options = JsonOptions());
-void FieldToJson(nlohmann::ordered_json& jdata, int data, const JsonOptions& options = JsonOptions());
-void FieldToJson(nlohmann::ordered_json& jdata, long data, const JsonOptions& options = JsonOptions());
-void FieldToJson(nlohmann::ordered_json& jdata, long long data, const JsonOptions& options = JsonOptions());
-void FieldToJson(nlohmann::ordered_json& jdata, unsigned short data, const JsonOptions& options = JsonOptions());
-void FieldToJson(nlohmann::ordered_json& jdata, unsigned int data, const JsonOptions& options = JsonOptions());
-void FieldToJson(nlohmann::ordered_json& jdata, unsigned long data, const JsonOptions& options = JsonOptions());
-void FieldToJson(nlohmann::ordered_json& jdata, unsigned long long data, const JsonOptions& options = JsonOptions());
+void FieldToJson(nlohmann::ordered_json& jdata, const short& data, const JsonOptions& options = JsonOptions());
+void FieldToJson(nlohmann::ordered_json& jdata, const int& data, const JsonOptions& options = JsonOptions());
+void FieldToJson(nlohmann::ordered_json& jdata, const long& data, const JsonOptions& options = JsonOptions());
+void FieldToJson(nlohmann::ordered_json& jdata, const long long& data, const JsonOptions& options = JsonOptions());
+void FieldToJson(nlohmann::ordered_json& jdata, const unsigned short& data, const JsonOptions& options = JsonOptions());
+void FieldToJson(nlohmann::ordered_json& jdata, const unsigned int& data, const JsonOptions& options = JsonOptions());
+void FieldToJson(nlohmann::ordered_json& jdata, const unsigned long& data, const JsonOptions& options = JsonOptions());
+void FieldToJson(nlohmann::ordered_json&   jdata,
+                 const unsigned long long& data,
+                 const JsonOptions&        options = JsonOptions());
 void FieldToJson(nlohmann::ordered_json& jdata, const std::nullptr_t data, const JsonOptions& options = JsonOptions());
 /// Convert floats to JSON, logging information loss when floats with no JSON
 /// number type representation are adjusted. The JSON library turns these numbers
@@ -92,7 +98,7 @@ void HandleToJson(nlohmann::ordered_json& jdata, const format::HandleId handle,
 /// VkBool32 to true or false. It should be fine for the signed Windows type
 /// BOOL too.
 void Bool32ToJson(nlohmann::ordered_json&  jdata,
-                  const uint32_t           data,
+                  const uint32_t&          data,
                   const util::JsonOptions& options = util::JsonOptions());
 
 /// @brief Convert an integer type to JSON but encoded in hex as a JSON string
