@@ -238,7 +238,7 @@ PageGuardManager::PageGuardManager(bool                 enable_copy_on_map,
     enable_separate_read_(enable_separate_read), unblock_sigsegv_(unblock_SIGSEGV),
     enable_signal_handler_watcher_(enable_signal_handler_watcher),
     signal_handler_watcher_max_restores_(signal_handler_watcher_max_restores),
-    enable_read_write_same_page_(expect_read_write_same_page), protection_mode_(protection_mode)
+    enable_read_write_same_page_(expect_read_write_same_page), protection_mode_(protection_mode), uffd_is_init_(false)
 {
     if (kUserFaultFdMode == protection_mode_ && !USERFAULTFD_SUPPORTED)
     {
@@ -743,13 +743,6 @@ void PageGuardManager::ProcessEntry(uint64_t                  memory_id,
     assert(memory_info != nullptr);
     assert(memory_info->is_modified);
 
-    uint32_t n_threads_to_wait = 0;
-
-    if (protection_mode_ == kUserFaultFdMode)
-    {
-        n_threads_to_wait = UffdBlockFaultingThreads(memory_info);
-    }
-
     bool   active_range = false;
     size_t start_index  = 0;
 
@@ -780,14 +773,14 @@ void PageGuardManager::ProcessEntry(uint64_t                  memory_id,
             {
                 memory_info->status_tracker.SetActiveReadBlock(i, false);
 
-                assert(memory_info->shadow_memory != nullptr);
-
-                void* page_address =
-                    static_cast<uint8_t*>(memory_info->aligned_address) + (i << system_page_pot_shift_);
-                size_t segment_size = GetMemorySegmentSize(memory_info, i);
-
                 if (protection_mode_ == kMProtectMode)
                 {
+                    assert(memory_info->shadow_memory != nullptr);
+
+                    void* page_address =
+                        static_cast<uint8_t*>(memory_info->aligned_address) + (i << system_page_pot_shift_);
+                    size_t segment_size = GetMemorySegmentSize(memory_info, i);
+
                     SetMemoryProtection(page_address, segment_size, kGuardReadWriteProtect);
                 }
             }
@@ -806,12 +799,6 @@ void PageGuardManager::ProcessEntry(uint64_t                  memory_id,
     {
         ProcessActiveRange(memory_id, memory_info, start_index, memory_info->total_pages, handle_modified);
     }
-
-    // Unblock threads
-    if (protection_mode_ == kUserFaultFdMode)
-    {
-        UffdUnblockFaultingThreads(memory_info, n_threads_to_wait);
-    }
 }
 
 void PageGuardManager::ProcessActiveRange(uint64_t                  memory_id,
@@ -848,6 +835,7 @@ void PageGuardManager::ProcessActiveRange(uint64_t                  memory_id,
         else if (kUserFaultFdMode == protection_mode_)
         {
             assert(memory_info->aligned_address == memory_info->shadow_memory);
+            // uffd requires page aligned addresses and sizes.
             UffdUnregisterMemory(guard_address, page_count << system_page_pot_shift_);
         }
 
@@ -876,7 +864,7 @@ void PageGuardManager::ProcessActiveRange(uint64_t                  memory_id,
         }
         else if (kUserFaultFdMode == protection_mode_)
         {
-            UffdResetRegion(guard_address, page_count << system_page_pot_shift_);
+            UffdResetRegion(guard_address, page_range);
         }
     }
     else
@@ -1011,7 +999,23 @@ void* PageGuardManager::AddTrackedMemory(uint64_t  memory_id,
 
     if (aligned_address != nullptr)
     {
-        size_t guard_range       = mapped_range + aligned_offset;
+        size_t guard_range = mapped_range + aligned_offset;
+
+        // Userfaultfd requires the registered region to be multiples of the page size
+        if (kUserFaultFdMode == protection_mode_ && guard_range != GetAlignedSize(guard_range))
+        {
+            if (!use_shadow_memory)
+            {
+                assert(shadow_memory == nullptr);
+                GFXRECON_LOG_WARNING("Registering an externally allocated memory region to uffd using a range (%zu) "
+                                     "greater than the requested/original size (%zu).",
+                                     GetAlignedSize(guard_range),
+                                     guard_range);
+            }
+
+            guard_range = GetAlignedSize(guard_range);
+        }
+
         size_t total_pages       = guard_range >> system_page_pot_shift_;
         size_t last_segment_size = guard_range & (system_page_size_ - 1); // guard_range % system_page_size_
 
@@ -1092,8 +1096,7 @@ void* PageGuardManager::AddTrackedMemory(uint64_t  memory_id,
             }
             else
             {
-                assert(shadow_memory == aligned_address);
-                success = UffdRegisterMemory(shadow_memory, shadow_size);
+                success = UffdRegisterMemory(aligned_address, guard_range);
             }
         }
 
@@ -1221,6 +1224,12 @@ void PageGuardManager::ProcessMemoryEntry(uint64_t memory_id, const ModifiedMemo
 
     auto entry = memory_info_.find(memory_id);
 
+    uint32_t n_threads_to_wait = 0;
+    if (protection_mode_ == kUserFaultFdMode)
+    {
+        n_threads_to_wait = UffdBlockFaultingThreads();
+    }
+
     if (entry != memory_info_.end())
     {
         auto memory_info = &entry->second;
@@ -1237,12 +1246,24 @@ void PageGuardManager::ProcessMemoryEntry(uint64_t memory_id, const ModifiedMemo
             ProcessEntry(entry->first, memory_info, handle_modified);
         }
     }
+
+    // Unblock threads
+    if (protection_mode_ == kUserFaultFdMode)
+    {
+        UffdUnblockFaultingThreads(n_threads_to_wait);
+    }
 }
 
 void PageGuardManager::ProcessMemoryEntries(const ModifiedMemoryFunc& handle_modified)
 {
     std::lock_guard<std::mutex> lock(tracked_memory_lock_);
 
+    uint32_t n_threads_to_wait = 0;
+    if (protection_mode_ == kUserFaultFdMode)
+    {
+        n_threads_to_wait = UffdBlockFaultingThreads();
+    }
+
     for (auto entry = memory_info_.begin(); entry != memory_info_.end(); ++entry)
     {
         auto memory_info = &entry->second;
@@ -1259,6 +1280,12 @@ void PageGuardManager::ProcessMemoryEntries(const ModifiedMemoryFunc& handle_mod
             ProcessEntry(entry->first, memory_info, handle_modified);
         }
     }
+
+    // Unblock threads
+    if (protection_mode_ == kUserFaultFdMode)
+    {
+        UffdUnblockFaultingThreads(n_threads_to_wait);
+    }
 }
 
 bool PageGuardManager::HandleGuardPageViolation(void* address, bool is_write, bool clear_guard)
