@@ -263,6 +263,15 @@ int main(int argc, const char** argv)
                 {
 #if defined(D3D12_SUPPORT)
                     dx12_replay_consumer.PostReplay();
+                    if (!dx_replay_options.screenshot_ranges.empty() && !file_processor.UsesFrameMarkers() &&
+                        (dx12_replay_consumer.GetDXGITestPresentCount() > 0))
+                    {
+                        GFXRECON_LOG_WARNING_ONCE(
+                            "This capture contains %" PRIu32
+                            " calls to IDXGISwapChain::Present with flag DXGI_PRESENT_TEST and no frame end markers. "
+                            "Screenshot frame indexing may have changed since capture.",
+                            dx12_replay_consumer.GetDXGITestPresentCount());
+                    }
 #endif
 
                     fps_info.LogToConsole();
